Menu Visual Test: Default

## Default inline menu

- Aberdeen
- Ada
- Adamsville
- Addyston
- Delphi
- Saarland
- Salzburg

## Inline with disabled items and submenus

- Aberdeen
- Ada
- Adamsville
- Addyston
- Delphi
  - Ada
  - Saarland
  - Salzburg
- Saarland
- Salzburg
  - Delphi
    - Ada
    - Saarland
    - Salzburg
  - Delphi
    - Ada
    - Saarland
    - Salzburg
  - Perch
- Amesville

## Menu with icons

- Aberdeen
- Ada
- Adamsville
- Addyston
- Delphi
  - Ada
  - Saarland
  - Salzburg
- Saarland
- Salzburg
  - Delphi
    - Ada
    - Saarland
    - Salzburg
  - Delphi
    - Ada
    - Saarland
    - Salzburg
  - Perch

## Long menu with scroll overflow, to test menu's scroll-on-keypress behaviour

- Aberdeen
- Ada
- Adamsville
- Addyston
- Adelphi
- Adena
- Adrian
- Akron
- Albany
- Alexandria
- Alger
- Alledonia
- Alliance
- Alpha
- Alvada
- Alvordton
- Amanda
- Amelia
- Amesville
- Aberdeen
- Ada
- Adamsville
- Addyston
- Adelphi
- Adena
- Adrian
- Akron
- Albany
- Alexandria
- Alger
- Alledonia
- Alliance
- Alpha
- Alvada
- Alvordton
- Amanda
- Amelia
- Amesville

## Menu with custom markup

> Aberdeen

> Ada

> Adamsville

> Addyston

> Delphi

> > Ada

> > Saarland

> > Salzburg

> Saarland

> Salzburg

> > Delphi

> > > Ada

> > > Saarland

> > > Salzburg

> > Delphi

> > > Ada

> > > Saarland

> > > Salzburg

> > Perch

## Menu with custom markup, multi-line items and a custom submenu icon

John Doe 78 West Main St Apt 3A Bloomsburg, PA 12345
Jane Doe 78 West Main St Apt 3A Bloomsburg, PA 12345
James Doe 78 West Main St Apt 3A Bloomsburg, PA 12345
Jenny Doe 78 West Main St Apt 3A Bloomsburg, PA 12345
John Doe 78 West Main St Apt 3A Bloomsburg, PA 12345
Ada
Saarland
Salzburg

## Inline with dividers and group labels

- Group 1
- Aberdeen
- Ada
- Adamsville
- Addyston
- Group 2
- Delphi
  - Ada
  - Saarland
  - Salzburg
- Saarland
- ---
- Group 3
- Salzburg
  - Delphi
    - Ada
    - -
    - Saarland
    - —
    - Salzburg
    - –
  - Delphi
    - Ada
    - Saarland
    - Salzburg
  - Perch
- Amesville

Log: